@@ -1,6 +1,7 @@
+# -*- coding: utf-8 -*-
 from asaloader.do_prog import do_prog
 from asaloader.device import device_list
-from asaloader.ihex import isIHex
+from asaloader.ihex import is_ihex
 from asaloader.locale import _
 
 import argparse
@@ -138,7 +139,7 @@ def prog_args_handler(args):
             print('Error: Cannot find flash binary file {0}.'.format(
                 args.flash_file))
             sys.exit(1)
-        elif not isIHex(args.flash_file):
+        elif not is_ihex(args.flash_file):
             print('Error: The flash binary file {0} is not ihex formatted.'.format(
                 args.flash_file))
             sys.exit(1)
@@ -150,7 +151,7 @@ def prog_args_handler(args):
             print(_('Error: Cannot find eeprom binary file {0}.').format(
                 args.eep_file))
             sys.exit(1)
-        elif not isIHex(args.eep_file):
+        elif not is_ihex(args.eep_file):
             print(_('Error: The eeprom binary file {0} is not ihex formatted.').format(
                 args.eep_file))
             sys.exit(1)
